==> m-dynamic-dialog-0.1.10.tgz: package/README.md <==
# Usage

    Inject the MDialogService into the component from which you will open 
    the dialog. The method called 'open(YourComponent, Properties)' 
    shows your chosen component as dialog. See Example below: 


    export class MyComponent{
        constructor(private MDynamicDialogService dialogService){}

        onOpenClick(){
            this.dialogService.open(SomeComponent, {
                height: "30vh",
                width: "50vh",
                data: "some data"
            })
        }
    }

# List of properties: 
    title: string - The title in the header of dialog
    height: string - The height applies only to the body of the dialog.
    width: string - The width applies only to the body of the dialog.
    headerHeight: string - The dialog header height. Default: "7vh
    footerHeight: string - The dialog header height. Default: "5vh
    showHeader: boolean - Hide the header if you want to use your own
    showFooter: boolean - Hide the footer if you want to use your own
    showSaveButton: boolean - Hide the save button if you want to use your ownMDynamic
    showCloseButton: boolean - Hide the save button if you want to use your own
    saveButtonLabel: string - Changes the save button label
    closeButtonLabel: string - Changes the close button label
    data: any - The data you want to pass to the dialog. 
                You can access it by injecting MDynamicDialogData
                 in the dialog component.

# Events
    The open() method returns a MDynamicDialogReference which you can use to listen 
    for close and save events. You can also inject the MDynamicDialogReference in the 
    dialog component and use it to trigger the save and close events. With this you 
    can remove the footer and use your own buttons for saving and closing. 
    The MDynamicDialogReference refers only to the instance of the dialog which you have opened, 
    this means that you can open multiple dialogs and control 
    each other them with their own MDynamicDialogReference.

# Data
    You can pass data to the dialog in the properties parameter. 
    The second parameter in the example i showed above. 
    To access the data, inject MDynamicDialogData in the dialog component. 
    See example below

        export class MyComponent{
        constructor(private MDynamicDialogData dialogData){}

            ngOnInit(){
                console.log(dialogData.data);
            }
        }

# Confirmation box

    The MDynamicDialogService offers a method called openConfirmation(parameter: MConfirmationDialogParameter),
    it opens a confirm dialog and returns the reference of the dialog. The reference can be used to listen for
    the close event that show wether the user chose yes or no.

    Example:
    export class MyComponent{
        constructor(private MDynamicDialogService: dialogService){}

            yourMethod(){
                this.dialogService.openConfirmation({
                    height: "35vh", //default is "20vh"
                    width: "35vw" //default is "20vw"
                })
            }
        }

    The parameter can take these values:
     - height: The hight of the dialog
     - width: The width of the dialog
     - title: The title which you want to display
     - message: The message which you want to display
     - yesButtonLabel: Changes the yes button label
     - noButtonLabel: Changes the no button label

==> m-dynamic-dialog-0.3.0.tgz: package/README.md <==
# Usage

    Inject the MDialogService into the component from which you will open 
    the dialog. The method called 'open(YourComponent, Properties)' 
    shows your chosen component as dialog. See Example below: 


    export class MyComponent{
        constructor(private MDynamicDialogService dialogService){}

        onOpenClick(){
            this.dialogService.open(SomeComponent, {
                height: "30vh",
                width: "50vh",
                data: "some data"
            })
        }
    }

# List of properties: 
    title: string - The title in the header of dialog
    zIndex: Changes the default z-index
    height: string - The height applies only to the body of the dialog
    width: string - The width applies only to the body of the dialog
    headerHeight: string - The dialog header height. Default: "7vh
    footerHeight: string - The dialog header height. Default: "5vh
    showHeader: boolean - Hide the header if you want to use your own
    showFooter: boolean - Hide the footer if you want to use your own
    showSaveButton: boolean - Hide the save button if you want to use your ownMDynamic
    showCloseButton: boolean - Hide the save button if you want to use your own
    saveButtonLabel: string - Changes the save button label
    closeButtonLabel: string - Changes the close button label
    data: any - The data you want to pass to the dialog. 
                You can access it by injecting MDynamicDialogData
                 in the dialog component

# Events
    The open() method returns a MDynamicDialogReference which you can use to listen 
    for close and save events. You can also inject the MDynamicDialogReference in the 
    dialog component and use it to trigger the save and close events. With this you 
    can remove the footer and use your own buttons for saving and closing. 
    The MDynamicDialogReference refers only to the instance of the dialog which you have opened, 
    this means that you can open multiple dialogs and control 
    each other them with their own MDynamicDialogReference.

# Data
    You can pass data to the dialog in the properties parameter. 
    The second parameter in the example i showed above. 
    To access the data, inject MDynamicDialogData in the dialog component. 
    See example below

        export class MyComponent{
        constructor(private MDynamicDialogData dialogData){}

            ngOnInit(){
                console.log(dialogData.data);
            }
        }

# Confirmation box

    The MDynamicDialogService offers a method called openConfirmation(parameter: MConfirmationDialogParameter),
    it opens a confirm dialog and returns the reference of the dialog. The reference can be used to listen for
    the close event that show wether the user chose yes or no.

    Example:
    export class MyComponent{
        constructor(private MDynamicDialogService: dialogService){}

            yourMethod(){
                this.dialogService.openConfirmation({
                    height: "35vh", //default is "20vh"
                    width: "35vw" //default is "20vw"
                })
            }
        }

    The parameter can take these values:
     - height: The hight of the dialog
     - width: The width of the dialog
     - title: The title which you want to display
     - message: The message which you want to display
     - yesButtonLabel: Changes the yes button label
     - noButtonLabel: Changes the no button label
